==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acu&egrave;lh dau sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Lu articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'Li a minga d\'article &agrave;-n-aquela adre&ccedil;a ',
'aucun_auteur' => 'Li a minga d\'autor &agrave;-n-aquela adre&ccedil;a ',
'aucun_site' => 'Li a minga de sit &agrave;-n-aquela adre&ccedil;a ',
'aucune_breve' => 'Li a minga de br&egrave;va &agrave;-n-aquela adre&ccedil;a ',
'aucune_rubrique' => 'Li a minga de rubrica &agrave;-n-aquela adre&ccedil;a ',
'autres' => 'Autres',
'autres_breves' => 'Autri br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de m&ograve;ts claus',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Boanjorn',
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',
'copie_document_impossible' => 'Impossible de copiar lo document',

// D
'date' => 'Data',
'dernier_ajout' => 'Darri&egrave;r ajust',
'dernieres_breves' => 'Darri&egrave;ras br&egrave;vas',
'derniers_articles' => 'Darri&egrave;rs articles',
'derniers_commentaires' => 'Darri&egrave;rs comentaris',
'derniers_messages_forum' => 'Darri&egrave;rs messatges publicats dins lu f&ograve;ros',
'documents_interdits_forum' => 'Documents pro&iuml;bits dins lo f&ograve;ro',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En respoasta &agrave;&nbsp;:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats acceptats : @formats@.',
'forum' => 'F&ograve;ro',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Si conectar',

// M
'meme_auteur' => 'Dau meme autor',
'meme_rubrique' => 'Dins la mema rubrica',
'memes_auteurs' => 'Dei memes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de f&ograve;ro',
'messages_recents' => 'Lu messatges de f&ograve;ros mai recents',
'mots_clefs' => 'M&ograve;ts claus',
'mots_clefs_meme_groupe' => 'M&ograve;ts claus dins lo meme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Li nov&egrave;utats',
'nouveautes_web' => 'Nov&egrave;utats sus lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas nov&egrave;las',

// P
'page_precedente' => 'p&agrave;gina anteriora',
'page_suivante' => 'p&agrave;gina seguenta',
'par_auteur' => 'da',
'participer_site' => 'Pod&egrave;tz participar &agrave; la vida d\'aqueu sit e prepauar lu voastres articles en vos inscrivent &ccedil;ai sota. Receber&egrave;tz un e-mail que v\'indicar&agrave; lu voastres c&ograve;des per accedir &agrave; l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepauar un site &agrave; ajustar dins aquela rubrica&nbsp;:',

// R
'repondre_article' => 'Respoandre &agrave;-n-aquel article',
'repondre_breve' => 'Respoandre &agrave;-n-aquela br&egrave;va',
'repondre_message' => 'Respoandre &agrave;-n-aqueu messatge',
'resultats_recherche' => 'Resultats de la rec&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei f&ograve;ros',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realisat emb&eacute; SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam',
'suite' => 'seguida',
'sur_web' => 'Sus lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vequ&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa lu articles e br&egrave;vas publicats desp&iacute;',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'Veire l\'esqueleta d\'aquela p&agrave;gina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acu&egrave;lh dau sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Lu articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'Li a minga d\'article &agrave;-n-aquela adre&ccedil;a ',
'aucun_auteur' => 'Li a minga d\'autor &agrave;-n-aquela adre&ccedil;a ',
'aucun_site' => 'Li a minga de sit &agrave;-n-aquela adre&ccedil;a ',
'aucune_breve' => 'Li a minga de br&egrave;va &agrave;-n-aquela adre&ccedil;a ',
'aucune_rubrique' => 'Li a minga de rubrica &agrave;-n-aquela adre&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres',
'autres_breves' => 'Autri br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de m&ograve;ts claus',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'Boanjorn',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',
'copie_document_impossible' => 'Impossible de copiar lo document',

// D
'date' => 'Data',
'dernier_ajout' => 'Darri&egrave;r ajust',
'dernieres_breves' => 'Darri&egrave;ras br&egrave;vas',
'derniers_articles' => 'Darri&egrave;rs articles',
'derniers_commentaires' => 'Darri&egrave;rs comentaris',
'derniers_messages_forum' => 'Darri&egrave;rs messatges publicats dins lu f&ograve;ros',
'documents_interdits_forum' => 'Documents pro&iuml;bits dins lo f&ograve;ro',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En respoasta &agrave;&nbsp;:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats acceptats : @formats@.',
'forum' => 'F&ograve;ro',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Si conectar',

// M
'meme_auteur' => 'Dau meme autor',
'meme_rubrique' => 'Dins la mema rubrica',
'memes_auteurs' => 'Dei memes autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de f&ograve;ro',
'messages_recents' => 'Lu messatges de f&ograve;ros mai recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'M&ograve;ts claus',
'mots_clefs_meme_groupe' => 'M&ograve;ts claus dins lo meme grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Li nov&egrave;utats',
'nouveautes_web' => 'Nov&egrave;utats sus lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas nov&egrave;las',

// P
'page_precedente' => 'p&agrave;gina anteriora',
'page_suivante' => 'p&agrave;gina seguenta',
'par_auteur' => 'da',
'participer_site' => 'Pod&egrave;tz participar &agrave; la vida d\'aqueu sit e prepauar lu voastres articles en vos inscrivent &ccedil;ai sota. Receber&egrave;tz un e-mail que v\'indicar&agrave; lu voastres c&ograve;des per accedir &agrave; l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepauar un site &agrave; ajustar dins aquela rubrica&nbsp;:',

// R
'repondre_article' => 'Respoandre &agrave;-n-aquel article',
'repondre_breve' => 'Respoandre &agrave;-n-aquela br&egrave;va',
'repondre_message' => 'Respoandre &agrave;-n-aqueu messatge',
'resultats_recherche' => 'Resultats de la rec&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei f&ograve;ros',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realisat emb&eacute; SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam',
'suite' => 'seguida',
'sur_web' => 'Sus lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vequ&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa lu articles e br&egrave;vas publicats desp&iacute;',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'Veire l\'esqueleta d\'aquela p&agrave;gina'
);

?>
